@@ -1,14 +1,14 @@
 /**
-* Copyright (c) 2006-2011 LOVE Development Team
-* 
+* Copyright (c) 2006-2012 LOVE Development Team
+*
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any damages
 * arising from the use of this software.
-* 
+*
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
-* 
+*
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software
 *    in a product, an acknowledgment in the product documentation would be
@@ -35,6 +35,8 @@ namespace sdl
 	int w_poll(lua_State * L);
 	int w_wait(lua_State * L);
 	int w_push(lua_State * L);
+	int w_clear(lua_State * L);
+	int w_quit(lua_State * L);
 
 	extern "C" LOVE_EXPORT int luaopen_love_event(lua_State * L);
 
