@@ -1,14 +1,14 @@
 /**
-* Copyright (c) 2006-2011 LOVE Development Team
-* 
+* Copyright (c) 2006-2012 LOVE Development Team
+*
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any damages
 * arising from the use of this software.
-* 
+*
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
-* 
+*
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software
 *    in a product, an acknowledgment in the product documentation would be
@@ -28,13 +28,14 @@
 #include <common/Data.h>
 #include <common/Object.h>
 #include <common/StringMap.h>
+#include <common/int.h>
 
 namespace love
 {
 namespace filesystem
 {
 	/**
-	* A File interface, providing generic means of reading from and 
+	* A File interface, providing generic means of reading from and
 	* writing to files.
 	**/
 	class File : public Object
@@ -56,7 +57,7 @@ namespace filesystem
 		/**
 		* Used to indicate ALL data in a file.
 		**/
-		static const int ALL = -1;
+		static const int64 ALL = -1;
 
 		/**
 		* Destructor.
@@ -65,7 +66,7 @@ namespace filesystem
 
 		/**
 		* Opens the file in a certain mode.
-		* 
+		*
 		* @param mode READ, WRITE, APPEND.
 		* @return True if successful, false otherwise.
 		**/
@@ -73,77 +74,77 @@ namespace filesystem
 
 		/**
 		* Closes the file.
-		* 
+		*
 		* @return True if successful, false otherwise.
 		**/
 		virtual bool close() = 0;
 
 		/**
 		* Gets the size of the file.
-		* 
+		*
 		* @return The size of the file.
 		**/
-		virtual unsigned int getSize() = 0;
+		virtual int64 getSize() = 0;
 
 		/**
 		* Reads data from the file and allocates a Data object.
-		* 
+		*
 		* @param size The number of bytes to attempt reading, or -1 for EOF.
 		* @return A newly allocated Data object.
 		**/
-		virtual Data * read(int size = ALL) = 0;
+		virtual Data * read(int64 size = ALL) = 0;
 
 		/**
 		* Reads data into the destination buffer.
-		* 
+		*
 		* @param dst The destination buffer.
 		* @param size The number of bytes to attempt reading.
 		* @return The number of bytes actually read.
 		**/
-		virtual int read(void * dst, int size) = 0;
+		virtual int64 read(void * dst, int64 size) = 0;
 
 		/**
 		* Writes data into the File.
-		* 
+		*
 		* @param data The source buffer.
 		* @param size The size of the buffer.
 		* @return True of success, false otherwise.
 		**/
-		virtual bool write(const void * data, int size) = 0;
+		virtual bool write(const void * data, int64 size) = 0;
 
 		/**
 		* Writes a Data object into the File.
-		* 
+		*
 		* @param data The data object to write into the file.
 		* @param size The number of bytes to attempt writing, or -1 for everything.
 		* @return True of success, false otherwise.
 		**/
-		virtual bool write(const Data * data, int size = ALL) = 0;
+		virtual bool write(const Data * data, int64 size = ALL) = 0;
 
 		/**
 		* Checks whether we are currently at end-of-file.
-		* 
+		*
 		* @return True if EOF, false otherwise.
 		**/
 		virtual bool eof() = 0;
 
 		/**
 		* Gets the current position in the File.
-		* 
+		*
 		* @return The current byte position in the File.
 		**/
-		virtual int tell() = 0;
+		virtual int64 tell() = 0;
 
 		/**
 		* Seeks to a certain position in the File.
-		* 
+		*
 		* @param pos The byte position in the file.
 		* @return True on success, false otherwise.
 		**/
-		virtual bool seek(int pos) = 0;
+		virtual bool seek(uint64 pos) = 0;
 
 		/**
-		* Gets the current mode of the File. 
+		* Gets the current mode of the File.
 		* @return The current mode of the File; CLOSED, READ, WRITE or APPEND.
 		**/
 		virtual Mode getMode() = 0;
