@@ -1,14 +1,14 @@
 /**
-* Copyright (c) 2006-2011 LOVE Development Team
-* 
+* Copyright (c) 2006-2012 LOVE Development Team
+*
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any damages
 * arising from the use of this software.
-* 
+*
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
-* 
+*
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software
 *    in a product, an acknowledgment in the product documentation would be
@@ -33,7 +33,7 @@ namespace sdl
 		: joysticks(0)
 	{
 		// Init the SDL joystick system.
-		if(SDL_InitSubSystem(SDL_INIT_JOYSTICK) < 0)
+		if (SDL_InitSubSystem(SDL_INIT_JOYSTICK) < 0)
 			throw Exception(SDL_GetError());
 
 		// Start joystick event watching.
@@ -43,16 +43,16 @@ namespace sdl
 		int numjoysticks = this->getNumJoysticks();
 		this->joysticks = (SDL_Joystick **)calloc(numjoysticks, sizeof(SDL_Joystick*));
 
-		for(int i = 0;i<numjoysticks;i++)
+		for (int i = 0;i<numjoysticks;i++)
 			this->open(i);
 	}
 
 	Joystick::~Joystick()
 	{
 		// Closes any open joysticks.
-		for(int i = 0; i != getNumJoysticks(); i++)
+		for (int i = 0; i != getNumJoysticks(); i++)
 		{
-			if(isOpen(i))
+			if (isOpen(i))
 				close(i);
 		}
 
@@ -84,13 +84,13 @@ namespace sdl
 
 	bool Joystick::open(int index)
 	{
-		if(isOpen(index))
+		if (isOpen(index))
 			return true;
 
-		if(!checkIndex(index))
+		if (!checkIndex(index))
 			return false;
 
-		if(!(joysticks[index] = SDL_JoystickOpen(index)) )
+		if (!(joysticks[index] = SDL_JoystickOpen(index)) )
 			return false;
 
 		return true;
@@ -98,7 +98,7 @@ namespace sdl
 
 	bool Joystick::isOpen(int index)
 	{
-		if(!checkIndex(index))
+		if (!checkIndex(index))
 			return false;
 
 		return joysticks[index] != 0 ? true : false;
@@ -106,10 +106,10 @@ namespace sdl
 
 	bool Joystick::verifyJoystick(int index)
 	{
-		if(!checkIndex(index))
+		if (!checkIndex(index))
 			return false;
 
-		if(!isOpen(index))
+		if (!isOpen(index))
 			return false;
 
 		return true;
@@ -137,34 +137,34 @@ namespace sdl
 
 	float Joystick::clampval(float x)
 	{
-		if(fabs((double)x) < 0.01) return 0.0f;
-		if(x < -0.99f) return -1.0f;
-		if(x > 0.99f) return 1.0f;
+		if (fabs((double)x) < 0.01) return 0.0f;
+		if (x < -0.99f) return -1.0f;
+		if (x > 0.99f) return 1.0f;
 		return x;
 	}
 
 	float Joystick::getAxis(int index, int axis)
 	{
-		if(!verifyJoystick(index))
+		if (!verifyJoystick(index))
 			return 0;
 
-		if(axis >= getNumAxes(index))
+		if (axis >= getNumAxes(index))
 			return 0;
-		
+
 		return clampval(((float)SDL_JoystickGetAxis(joysticks[index], axis))/32768.0f);
 	}
 
 	int Joystick::getAxes(lua_State * L)
 	{
 		love::luax_assert_argc(L, 1, 1);
-		int index = (int)lua_tointeger(L, 1);
+		int index = (int)lua_tointeger(L, 1) - 1;
 
-		if(!verifyJoystick(index))
+		if (!verifyJoystick(index))
 			return 0;
 
 		int num = getNumAxes(index);
 
-		for(int i = 0; i<num; i++)
+		for (int i = 0; i<num; i++)
 			lua_pushnumber(L, clampval(((float)SDL_JoystickGetAxis(joysticks[index], i))/32768.0f));
 		return num;
 	}
@@ -172,42 +172,47 @@ namespace sdl
 	int Joystick::getBall(lua_State * L)
 	{
 		love::luax_assert_argc(L, 2, 2);
-		int index = (int)lua_tointeger(L, 1);
-		int ball = (int)lua_tointeger(L, 2);
+		int index = (int)lua_tointeger(L, 1) - 1;
+		int ball = (int)lua_tointeger(L, 2) - 1;
 
-		if(!verifyJoystick(index))
+		if (!verifyJoystick(index))
 			return 0;
 
-		if(ball >= getNumBalls(index))
+		if (ball >= getNumBalls(index))
 			return 0;
 
 		int dx, dy;
 		SDL_JoystickGetBall(joysticks[index], ball, &dx, &dy);
-		
+
 		lua_pushnumber(L, dx);
 		lua_pushnumber(L, dy);
-		return 2;		
+		return 2;
 	}
 
-	bool Joystick::isDown(int index, int button)
+	bool Joystick::isDown(int index, int * buttonlist)
 	{
-		if(!verifyJoystick(index))
+		if (!verifyJoystick(index))
 			return false;
 
-		if(button >= getNumButtons(index))
-			return false;
+		int num = getNumButtons(index);
 
-		return (SDL_JoystickGetButton(joysticks[index], button) == 1);
+		for (int button = *buttonlist; button != -1; button = *(++buttonlist))
+		{
+			if (button >= 0 && button < num && SDL_JoystickGetButton(joysticks[index], button) == 1)
+				return true;
+		}
+
+		return false;
 	}
 
 	Joystick::Hat Joystick::getHat(int index, int hat)
 	{
 		Hat h = HAT_INVALID;
 
-		if(!verifyJoystick(index))
+		if (!verifyJoystick(index))
 			return h;
 
-		if(hat >= getNumHats(index))
+		if (hat >= getNumHats(index))
 			return h;
 
 		hats.find(SDL_JoystickGetHat(joysticks[index], hat), h);
@@ -217,17 +222,17 @@ namespace sdl
 
 	void Joystick::close(int index)
 	{
-		if(!checkIndex(index))
+		if (!checkIndex(index))
 			return;
 
-		if(joysticks[index]!=0)
+		if (joysticks[index]!=0)
 		{
 			SDL_JoystickClose(joysticks[index]);
 			joysticks[index] = 0;
 		}
 	}
 
-	EnumMap<Joystick::Hat, Uint8, Joystick::HAT_MAX_ENUM>::Entry Joystick::hatEntries[] = 
+	EnumMap<Joystick::Hat, Uint8, Joystick::HAT_MAX_ENUM>::Entry Joystick::hatEntries[] =
 	{
 		{Joystick::HAT_CENTERED, SDL_HAT_CENTERED},
 		{Joystick::HAT_UP, SDL_HAT_UP},
