@@ -1,14 +1,14 @@
 /**
-* Copyright (c) 2006-2011 LOVE Development Team
-* 
+* Copyright (c) 2006-2012 LOVE Development Team
+*
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any damages
 * arising from the use of this software.
-* 
+*
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
-* 
+*
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software
 *    in a product, an acknowledgment in the product documentation would be
@@ -30,7 +30,10 @@ namespace box2d
 {
 	Joint * luax_checkjoint(lua_State * L, int idx)
 	{
-		return luax_checktype<Joint>(L, idx, "Joint", PHYSICS_JOINT_T);
+		Joint * t = luax_checktype<Joint>(L, idx, "Joint", PHYSICS_JOINT_T);
+		if (!t->isValid())
+			luaL_error(L, "Attempt to use destroyed joint.");
+		return t;
 	}
 
 	int w_Joint_getType(lua_State * L)
@@ -59,18 +62,11 @@ namespace box2d
 	int w_Joint_getReactionTorque(lua_State * L)
 	{
 		Joint * t = luax_checkjoint(L, 1);
-		lua_pushnumber(L, t->getReactionTorque());
+		float inv_dt = (float)luaL_checknumber(L, 2);
+		lua_pushnumber(L, t->getReactionTorque(inv_dt));
 		return 1;
 	}
 
-	int w_Joint_setCollideConnected(lua_State * L)
-	{
-		Joint * t = luax_checkjoint(L, 1);
-		bool arg1 = luax_toboolean(L, 2);
-		t->setCollideConnected(arg1);
-		return 0;
-	}
-
 	int w_Joint_getCollideConnected(lua_State * L)
 	{
 		Joint * t = luax_checkjoint(L, 1);
@@ -80,12 +76,15 @@ namespace box2d
 
 	int w_Joint_destroy(lua_State * L)
 	{
-		Proxy * p = (Proxy *)lua_touserdata(L, 1);
-		p->own = false;
-
-		Joint * t = (Joint *)p->data;
-		t->release();
-
+		Joint * t = luax_checkjoint(L, 1);
+		try
+		{
+			t->destroyJoint();
+		}
+		catch (love::Exception & e)
+		{
+			luaL_error(L, "%s", e.what());
+		}
 		return 0;
 	}
 
@@ -94,13 +93,12 @@ namespace box2d
 		{ "getAnchors", w_Joint_getAnchors },
 		{ "getReactionForce", w_Joint_getReactionForce },
 		{ "getReactionTorque", w_Joint_getReactionTorque },
-		{ "setCollideConnected", w_Joint_setCollideConnected },
 		{ "getCollideConnected", w_Joint_getCollideConnected },
 		{ "destroy", w_Joint_destroy },
 		{ 0, 0 }
 	};
 
-	int luaopen_joint(lua_State * L)
+	extern "C" int luaopen_joint(lua_State * L)
 	{
 		return luax_register_type(L, "Joint", functions);
 	}
